debits package
==============

Subpackages
-----------

.. toctree::

    debits.debits_base
    debits.debits_test
    debits.paypal

Module contents
---------------

.. automodule:: debits
    :members:
    :undoc-members:
    :show-inheritance:
